==> doxygen_1.4.6.orig.tar.gz: doxygen-1.4.6/src/doxygen_css.h <==
"BODY,H1,H2,H3,H4,H5,H6,P,CENTER,TD,TH,UL,DL,DIV {\n"
"	font-family: Geneva, Arial, Helvetica, sans-serif;\n"
"}\n"
"BODY,TD {\n"
"       font-size: 90%;\n"
"}\n"
"H1 {\n"
"	text-align: center;\n"
"       font-size: 160%;\n"
"}\n"
"H2 {\n"
"       font-size: 120%;\n"
"}\n"
"H3 {\n"
"       font-size: 100%;\n"
"}\n"
"CAPTION { font-weight: bold }\n"
"DIV.qindex {\n"
"	width: 100%;\n"
"	background-color: #e8eef2;\n"
"	border: 1px solid #84b0c7;\n"
"	text-align: center;\n"
"	margin: 2px;\n"
"	padding: 2px;\n"
"	line-height: 140%;\n"
"}\n"
"DIV.nav {\n"
"	width: 100%;\n"
"	background-color: #e8eef2;\n"
"	border: 1px solid #84b0c7;\n"
"	text-align: center;\n"
"	margin: 2px;\n"
"	padding: 2px;\n"
"	line-height: 140%;\n"
"}\n"
"DIV.navtab {\n"
"       background-color: #e8eef2;\n"
"       border: 1px solid #84b0c7;\n"
"       text-align: center;\n"
"       margin: 2px;\n"
"       margin-right: 15px;\n"
"       padding: 2px;\n"
"}\n"
"TD.navtab {\n"
"       font-size: 70%;\n"
"}\n"
"A.qindex {\n"
"       text-decoration: none;\n"
"       font-weight: bold;\n"
"       color: #1A419D;\n"
"}\n"
"A.qindex:visited {\n"
"       text-decoration: none;\n"
"       font-weight: bold;\n"
"       color: #1A419D\n"
"}\n"
"A.qindex:hover {\n"
"	text-decoration: none;\n"
"	background-color: #ddddff;\n"
"}\n"
"A.qindexHL {\n"
"	text-decoration: none;\n"
"	font-weight: bold;\n"
"	background-color: #6666cc;\n"
"	color: #ffffff;\n"
"	border: 1px double #9295C2;\n"
"}\n"
"A.qindexHL:hover {\n"
"	text-decoration: none;\n"
"	background-color: #6666cc;\n"
"	color: #ffffff;\n"
"}\n"
"A.qindexHL:visited { text-decoration: none; background-color: #6666cc; color: #ffffff }\n"
"A.el { text-decoration: none; font-weight: bold }\n"
"A.elRef { font-weight: bold }\n"
"A.code:link { text-decoration: none; font-weight: normal; color: #0000FF}\n"
"A.code:visited { text-decoration: none; font-weight: normal; color: #0000FF}\n"
"A.codeRef:link { font-weight: normal; color: #0000FF}\n"
"A.codeRef:visited { font-weight: normal; color: #0000FF}\n"
"A:hover { text-decoration: none; background-color: #f2f2ff }\n"
"DL.el { margin-left: -1cm }\n"
".fragment {\n"
"       font-family: Fixed, monospace;\n"
"       font-size: 95%;\n"
"}\n"
"PRE.fragment {\n"
"	border: 1px solid #CCCCCC;\n"
"	background-color: #f5f5f5;\n"
"	margin-top: 4px;\n"
"	margin-bottom: 4px;\n"
"	margin-left: 2px;\n"
"	margin-right: 8px;\n"
"	padding-left: 6px;\n"
"	padding-right: 6px;\n"
"	padding-top: 4px;\n"
"	padding-bottom: 4px;\n"
"}\n"
"DIV.ah { background-color: black; font-weight: bold; color: #ffffff; margin-bottom: 3px; margin-top: 3px }\n"
"TD.md { background-color: #F4F4FB; font-weight: bold; }\n"
"TD.mdPrefix {\n"
"       background-color: #F4F4FB;\n"
"       color: #606060;\n"
"	font-size: 80%;\n"
"}\n"
"TD.mdname1 { background-color: #F4F4FB; font-weight: bold; color: #602020; }\n"
"TD.mdname { background-color: #F4F4FB; font-weight: bold; color: #602020; width: 600px; }\n"
"DIV.groupHeader {\n"
"       margin-left: 16px;\n"
"       margin-top: 12px;\n"
"       margin-bottom: 6px;\n"
"       font-weight: bold;\n"
"}\n"
"DIV.groupText { margin-left: 16px; font-style: italic; font-size: 90% }\n"
"BODY {\n"
"	background: white;\n"
"	color: black;\n"
"	margin-right: 20px;\n"
"	margin-left: 20px;\n"
"}\n"
"TD.indexkey {\n"
"	background-color: #e8eef2;\n"
"	font-weight: bold;\n"
"	padding-right  : 10px;\n"
"	padding-top    : 2px;\n"
"	padding-left   : 10px;\n"
"	padding-bottom : 2px;\n"
"	margin-left    : 0px;\n"
"	margin-right   : 0px;\n"
"	margin-top     : 2px;\n"
"	margin-bottom  : 2px;\n"
"	border: 1px solid #CCCCCC;\n"
"}\n"
"TD.indexvalue {\n"
"	background-color: #e8eef2;\n"
"	font-style: italic;\n"
"	padding-right  : 10px;\n"
"	padding-top    : 2px;\n"
"	padding-left   : 10px;\n"
"	padding-bottom : 2px;\n"
"	margin-left    : 0px;\n"
"	margin-right   : 0px;\n"
"	margin-top     : 2px;\n"
"	margin-bottom  : 2px;\n"
"	border: 1px solid #CCCCCC;\n"
"}\n"
"TR.memlist {\n"
"   background-color: #f0f0f0; \n"
"}\n"
"P.formulaDsp { text-align: center; }\n"
"IMG.formulaDsp { }\n"
"IMG.formulaInl { vertical-align: middle; }\n"
"SPAN.keyword       { color: #008000 }\n"
"SPAN.keywordtype   { color: #604020 }\n"
"SPAN.keywordflow   { color: #e08000 }\n"
"SPAN.comment       { color: #800000 }\n"
"SPAN.preprocessor  { color: #806020 }\n"
"SPAN.stringliteral { color: #002080 }\n"
"SPAN.charliteral   { color: #008080 }\n"
".mdTable {\n"
"	border: 1px solid #868686;\n"
"	background-color: #F4F4FB;\n"
"}\n"
".mdRow {\n"
"	padding: 8px 10px;\n"
"}\n"
".mdescLeft {\n"
"       padding: 0px 8px 4px 8px;\n"
"	font-size: 80%;\n"
"	font-style: italic;\n"
"	background-color: #FAFAFA;\n"
"	border-top: 1px none #E0E0E0;\n"
"	border-right: 1px none #E0E0E0;\n"
"	border-bottom: 1px none #E0E0E0;\n"
"	border-left: 1px none #E0E0E0;\n"
"	margin: 0px;\n"
"}\n"
".mdescRight {\n"
"       padding: 0px 8px 4px 8px;\n"
"	font-size: 80%;\n"
"	font-style: italic;\n"
"	background-color: #FAFAFA;\n"
"	border-top: 1px none #E0E0E0;\n"
"	border-right: 1px none #E0E0E0;\n"
"	border-bottom: 1px none #E0E0E0;\n"
"	border-left: 1px none #E0E0E0;\n"
"	margin: 0px;\n"
"}\n"
".memItemLeft {\n"
"	padding: 1px 0px 0px 8px;\n"
"	margin: 4px;\n"
"	border-top-width: 1px;\n"
"	border-right-width: 1px;\n"
"	border-bottom-width: 1px;\n"
"	border-left-width: 1px;\n"
"	border-top-color: #E0E0E0;\n"
"	border-right-color: #E0E0E0;\n"
"	border-bottom-color: #E0E0E0;\n"
"	border-left-color: #E0E0E0;\n"
"	border-top-style: solid;\n"
"	border-right-style: none;\n"
"	border-bottom-style: none;\n"
"	border-left-style: none;\n"
"	background-color: #FAFAFA;\n"
"	font-size: 80%;\n"
"}\n"
".memItemRight {\n"
"	padding: 1px 8px 0px 8px;\n"
"	margin: 4px;\n"
"	border-top-width: 1px;\n"
"	border-right-width: 1px;\n"
"	border-bottom-width: 1px;\n"
"	border-left-width: 1px;\n"
"	border-top-color: #E0E0E0;\n"
"	border-right-color: #E0E0E0;\n"
"	border-bottom-color: #E0E0E0;\n"
"	border-left-color: #E0E0E0;\n"
"	border-top-style: solid;\n"
"	border-right-style: none;\n"
"	border-bottom-style: none;\n"
"	border-left-style: none;\n"
"	background-color: #FAFAFA;\n"
"	font-size: 80%;\n"
"}\n"
".memTemplItemLeft {\n"
"	padding: 1px 0px 0px 8px;\n"
"	margin: 4px;\n"
"	border-top-width: 1px;\n"
"	border-right-width: 1px;\n"
"	border-bottom-width: 1px;\n"
"	border-left-width: 1px;\n"
"	border-top-color: #E0E0E0;\n"
"	border-right-color: #E0E0E0;\n"
"	border-bottom-color: #E0E0E0;\n"
"	border-left-color: #E0E0E0;\n"
"	border-top-style: none;\n"
"	border-right-style: none;\n"
"	border-bottom-style: none;\n"
"	border-left-style: none;\n"
"	background-color: #FAFAFA;\n"
"	font-size: 80%;\n"
"}\n"
".memTemplItemRight {\n"
"	padding: 1px 8px 0px 8px;\n"
"	margin: 4px;\n"
"	border-top-width: 1px;\n"
"	border-right-width: 1px;\n"
"	border-bottom-width: 1px;\n"
"	border-left-width: 1px;\n"
"	border-top-color: #E0E0E0;\n"
"	border-right-color: #E0E0E0;\n"
"	border-bottom-color: #E0E0E0;\n"
"	border-left-color: #E0E0E0;\n"
"	border-top-style: none;\n"
"	border-right-style: none;\n"
"	border-bottom-style: none;\n"
"	border-left-style: none;\n"
"	background-color: #FAFAFA;\n"
"	font-size: 80%;\n"
"}\n"
".memTemplParams {\n"
"	padding: 1px 0px 0px 8px;\n"
"	margin: 4px;\n"
"	border-top-width: 1px;\n"
"	border-right-width: 1px;\n"
"	border-bottom-width: 1px;\n"
"	border-left-width: 1px;\n"
"	border-top-color: #E0E0E0;\n"
"	border-right-color: #E0E0E0;\n"
"	border-bottom-color: #E0E0E0;\n"
"	border-left-color: #E0E0E0;\n"
"	border-top-style: solid;\n"
"	border-right-style: none;\n"
"	border-bottom-style: none;\n"
"	border-left-style: none;\n"
"       color: #606060;\n"
"	background-color: #FAFAFA;\n"
"	font-size: 80%;\n"
"}\n"
".search     { color: #003399;\n"
"              font-weight: bold;\n"
"}\n"
"FORM.search {\n"
"              margin-bottom: 0px;\n"
"              margin-top: 0px;\n"
"}\n"
"INPUT.search { font-size: 75%;\n"
"               color: #000080;\n"
"               font-weight: normal;\n"
"               background-color: #e8eef2;\n"
"}\n"
"TD.tiny      { font-size: 75%;\n"
"}\n"
"a {\n"
"	color: #1A41A8;\n"
"}\n"
"a:visited {\n"
"	color: #2A3798;\n"
"}\n"
".dirtab { padding: 4px;\n"
"          border-collapse: collapse;\n"
"          border: 1px solid #84b0c7;\n"
"}\n"
"TH.dirtab { background: #e8eef2;\n"
"            font-weight: bold;\n"
"}\n"
"HR { height: 1px;\n"
"     border: none;\n"
"     border-top: 1px solid black;\n"
"}\n"
"\n"

==> doxygen_1.5.5.orig.tar.gz: doxygen-1.5.5/src/doxygen_css.h <==
"BODY,H1,H2,H3,H4,H5,H6,P,CENTER,TD,TH,UL,DL,DIV {\n"
"	font-family: Geneva, Arial, Helvetica, sans-serif;\n"
"}\n"
"BODY,TD {\n"
"	font-size: 90%;\n"
"}\n"
"H1 {\n"
"	text-align: center;\n"
"	font-size: 160%;\n"
"}\n"
"H2 {\n"
"	font-size: 120%;\n"
"}\n"
"H3 {\n"
"	font-size: 100%;\n"
"}\n"
"CAPTION { \n"
"	font-weight: bold \n"
"}\n"
"DIV.qindex {\n"
"	width: 100%;\n"
"	background-color: #e8eef2;\n"
"	border: 1px solid #84b0c7;\n"
"	text-align: center;\n"
"	margin: 2px;\n"
"	padding: 2px;\n"
"	line-height: 140%;\n"
"}\n"
"DIV.navpath {\n"
"	width: 100%;\n"
"	background-color: #e8eef2;\n"
"	border: 1px solid #84b0c7;\n"
"	text-align: center;\n"
"	margin: 2px;\n"
"	padding: 2px;\n"
"	line-height: 140%;\n"
"}\n"
"DIV.navtab {\n"
"       background-color: #e8eef2;\n"
"       border: 1px solid #84b0c7;\n"
"       text-align: center;\n"
"       margin: 2px;\n"
"       margin-right: 15px;\n"
"       padding: 2px;\n"
"}\n"
"TD.navtab {\n"
"       font-size: 70%;\n"
"}\n"
"A.qindex {\n"
"       text-decoration: none;\n"
"       font-weight: bold;\n"
"       color: #1A419D;\n"
"}\n"
"A.qindex:visited {\n"
"       text-decoration: none;\n"
"       font-weight: bold;\n"
"       color: #1A419D\n"
"}\n"
"A.qindex:hover {\n"
"	text-decoration: none;\n"
"	background-color: #ddddff;\n"
"}\n"
"A.qindexHL {\n"
"	text-decoration: none;\n"
"	font-weight: bold;\n"
"	background-color: #6666cc;\n"
"	color: #ffffff;\n"
"	border: 1px double #9295C2;\n"
"}\n"
"A.qindexHL:hover {\n"
"	text-decoration: none;\n"
"	background-color: #6666cc;\n"
"	color: #ffffff;\n"
"}\n"
"A.qindexHL:visited { \n"
"	text-decoration: none; \n"
"	background-color: #6666cc; \n"
"	color: #ffffff \n"
"}\n"
"A.el { \n"
"	text-decoration: none; \n"
"	font-weight: bold \n"
"}\n"
"A.elRef { \n"
"	font-weight: bold \n"
"}\n"
"A.code:link { \n"
"	text-decoration: none; \n"
"	font-weight: normal; \n"
"	color: #0000FF\n"
"}\n"
"A.code:visited { \n"
"	text-decoration: none; \n"
"	font-weight: normal; \n"
"	color: #0000FF\n"
"}\n"
"A.codeRef:link { \n"
"	font-weight: normal; \n"
"	color: #0000FF\n"
"}\n"
"A.codeRef:visited { \n"
"	font-weight: normal; \n"
"	color: #0000FF\n"
"}\n"
"A:hover { \n"
"	text-decoration: none; 	\n"
"	background-color: #f2f2ff \n"
"}\n"
"DL.el { \n"
"	margin-left: -1cm \n"
"}\n"
".fragment {\n"
"       font-family: monospace, fixed;\n"
"       font-size: 95%;\n"
"}\n"
"PRE.fragment {\n"
"	border: 1px solid #CCCCCC;\n"
"	background-color: #f5f5f5;\n"
"	margin-top: 4px;\n"
"	margin-bottom: 4px;\n"
"	margin-left: 2px;\n"
"	margin-right: 8px;\n"
"	padding-left: 6px;\n"
"	padding-right: 6px;\n"
"	padding-top: 4px;\n"
"	padding-bottom: 4px;\n"
"}\n"
"DIV.ah { \n"
"	background-color: black; \n"
"	font-weight: bold; \n"
"	color: #ffffff; \n"
"	margin-bottom: 3px; \n"
"	margin-top: 3px \n"
"}\n"
"\n"
"DIV.groupHeader {\n"
"       margin-left: 16px;\n"
"       margin-top: 12px;\n"
"       margin-bottom: 6px;\n"
"       font-weight: bold;\n"
"}\n"
"DIV.groupText { \n"
"	margin-left: 16px; \n"
"	font-style: italic; \n"
"	font-size: 90% \n"
"}\n"
"BODY {\n"
"	background: white;\n"
"	color: black;\n"
"	margin-right: 20px;\n"
"	margin-left: 20px;\n"
"}\n"
"TD.indexkey {\n"
"	background-color: #e8eef2;\n"
"	font-weight: bold;\n"
"	padding-right  : 10px;\n"
"	padding-top    : 2px;\n"
"	padding-left   : 10px;\n"
"	padding-bottom : 2px;\n"
"	margin-left    : 0px;\n"
"	margin-right   : 0px;\n"
"	margin-top     : 2px;\n"
"	margin-bottom  : 2px;\n"
"	border: 1px solid #CCCCCC;\n"
"}\n"
"TD.indexvalue {\n"
"	background-color: #e8eef2;\n"
"	font-style: italic;\n"
"	padding-right  : 10px;\n"
"	padding-top    : 2px;\n"
"	padding-left   : 10px;\n"
"	padding-bottom : 2px;\n"
"	margin-left    : 0px;\n"
"	margin-right   : 0px;\n"
"	margin-top     : 2px;\n"
"	margin-bottom  : 2px;\n"
"	border: 1px solid #CCCCCC;\n"
"}\n"
"TR.memlist {\n"
"	background-color: #f0f0f0; \n"
"}\n"
"P.formulaDsp { \n"
"	text-align: center; \n"
"}\n"
"IMG.formulaDsp {\n"
"}\n"
"IMG.formulaInl { \n"
"	vertical-align: middle; \n"
"}\n"
"SPAN.keyword       { color: #008000 }\n"
"SPAN.keywordtype   { color: #604020 }\n"
"SPAN.keywordflow   { color: #e08000 }\n"
"SPAN.comment       { color: #800000 }\n"
"SPAN.preprocessor  { color: #806020 }\n"
"SPAN.stringliteral { color: #002080 }\n"
"SPAN.charliteral   { color: #008080 }\n"
"SPAN.vhdldigit     { color: #ff00ff }\n"
"SPAN.vhdlchar      { color: #000000 }\n"
"SPAN.vhdlkeyword   { color: #700070 }\n"
"SPAN.vhdllogic     { color: #ff0000 }\n"
"\n"
".mdescLeft {\n"
"	padding: 0px 8px 4px 8px;\n"
"	font-size: 80%;\n"
"	font-style: italic;\n"
"	background-color: #FAFAFA;\n"
"	border-top: 1px none #E0E0E0;\n"
"	border-right: 1px none #E0E0E0;\n"
"	border-bottom: 1px none #E0E0E0;\n"
"	border-left: 1px none #E0E0E0;\n"
"	margin: 0px;\n"
"}\n"
".mdescRight {\n"
"        padding: 0px 8px 4px 8px;\n"
"	font-size: 80%;\n"
"	font-style: italic;\n"
"	background-color: #FAFAFA;\n"
"	border-top: 1px none #E0E0E0;\n"
"	border-right: 1px none #E0E0E0;\n"
"	border-bottom: 1px none #E0E0E0;\n"
"	border-left: 1px none #E0E0E0;\n"
"	margin: 0px;\n"
"}\n"
".memItemLeft {\n"
"	padding: 1px 0px 0px 8px;\n"
"	margin: 4px;\n"
"	border-top-width: 1px;\n"
"	border-right-width: 1px;\n"
"	border-bottom-width: 1px;\n"
"	border-left-width: 1px;\n"
"	border-top-color: #E0E0E0;\n"
"	border-right-color: #E0E0E0;\n"
"	border-bottom-color: #E0E0E0;\n"
"	border-left-color: #E0E0E0;\n"
"	border-top-style: solid;\n"
"	border-right-style: none;\n"
"	border-bottom-style: none;\n"
"	border-left-style: none;\n"
"	background-color: #FAFAFA;\n"
"	font-size: 80%;\n"
"}\n"
".memItemRight {\n"
"	padding: 1px 8px 0px 8px;\n"
"	margin: 4px;\n"
"	border-top-width: 1px;\n"
"	border-right-width: 1px;\n"
"	border-bottom-width: 1px;\n"
"	border-left-width: 1px;\n"
"	border-top-color: #E0E0E0;\n"
"	border-right-color: #E0E0E0;\n"
"	border-bottom-color: #E0E0E0;\n"
"	border-left-color: #E0E0E0;\n"
"	border-top-style: solid;\n"
"	border-right-style: none;\n"
"	border-bottom-style: none;\n"
"	border-left-style: none;\n"
"	background-color: #FAFAFA;\n"
"	font-size: 80%;\n"
"}\n"
".memTemplItemLeft {\n"
"	padding: 1px 0px 0px 8px;\n"
"	margin: 4px;\n"
"	border-top-width: 1px;\n"
"	border-right-width: 1px;\n"
"	border-bottom-width: 1px;\n"
"	border-left-width: 1px;\n"
"	border-top-color: #E0E0E0;\n"
"	border-right-color: #E0E0E0;\n"
"	border-bottom-color: #E0E0E0;\n"
"	border-left-color: #E0E0E0;\n"
"	border-top-style: none;\n"
"	border-right-style: none;\n"
"	border-bottom-style: none;\n"
"	border-left-style: none;\n"
"	background-color: #FAFAFA;\n"
"	font-size: 80%;\n"
"}\n"
".memTemplItemRight {\n"
"	padding: 1px 8px 0px 8px;\n"
"	margin: 4px;\n"
"	border-top-width: 1px;\n"
"	border-right-width: 1px;\n"
"	border-bottom-width: 1px;\n"
"	border-left-width: 1px;\n"
"	border-top-color: #E0E0E0;\n"
"	border-right-color: #E0E0E0;\n"
"	border-bottom-color: #E0E0E0;\n"
"	border-left-color: #E0E0E0;\n"
"	border-top-style: none;\n"
"	border-right-style: none;\n"
"	border-bottom-style: none;\n"
"	border-left-style: none;\n"
"	background-color: #FAFAFA;\n"
"	font-size: 80%;\n"
"}\n"
".memTemplParams {\n"
"	padding: 1px 0px 0px 8px;\n"
"	margin: 4px;\n"
"	border-top-width: 1px;\n"
"	border-right-width: 1px;\n"
"	border-bottom-width: 1px;\n"
"	border-left-width: 1px;\n"
"	border-top-color: #E0E0E0;\n"
"	border-right-color: #E0E0E0;\n"
"	border-bottom-color: #E0E0E0;\n"
"	border-left-color: #E0E0E0;\n"
"	border-top-style: solid;\n"
"	border-right-style: none;\n"
"	border-bottom-style: none;\n"
"	border-left-style: none;\n"
"	color: #606060;\n"
"	background-color: #FAFAFA;\n"
"	font-size: 80%;\n"
"}\n"
".search { \n"
"	color: #003399;\n"
"	font-weight: bold;\n"
"}\n"
"FORM.search {\n"
"	margin-bottom: 0px;\n"
"	margin-top: 0px;\n"
"}\n"
"INPUT.search { \n"
"	font-size: 75%;\n"
"	color: #000080;\n"
"	font-weight: normal;\n"
"	background-color: #e8eef2;\n"
"}\n"
"TD.tiny { \n"
"	font-size: 75%;\n"
"}\n"
"a {\n"
"	color: #1A41A8;\n"
"}\n"
"a:visited {\n"
"	color: #2A3798;\n"
"}\n"
".dirtab { \n"
"	padding: 4px;\n"
"	border-collapse: collapse;\n"
"	border: 1px solid #84b0c7;\n"
"}\n"
"TH.dirtab { \n"
"	background: #e8eef2;\n"
"	font-weight: bold;\n"
"}\n"
"HR { \n"
"	height: 1px;\n"
"	border: none;\n"
"	border-top: 1px solid black;\n"
"}\n"
"\n"
"/* Style for detailed member documentation */\n"
".memtemplate {\n"
"	font-size: 80%;\n"
"	color: #606060;\n"
"	font-weight: normal;\n"
"	margin-left: 3px;\n"
"} \n"
".memnav { \n"
"	background-color: #e8eef2;\n"
"	border: 1px solid #84b0c7;\n"
"	text-align: center;\n"
"	margin: 2px;\n"
"	margin-right: 15px;\n"
"	padding: 2px;\n"
"}\n"
".memitem {\n"
"	padding: 4px;\n"
"	background-color: #eef3f5;\n"
"	border-width: 1px;\n"
"	border-style: solid;\n"
"	border-color: #dedeee;\n"
"	-moz-border-radius: 8px 8px 8px 8px;\n"
"}\n"
".memname {\n"
"	white-space: nowrap;\n"
"	font-weight: bold;\n"
"}\n"
".memdoc{\n"
"	padding-left: 10px;\n"
"}\n"
".memproto {\n"
"	background-color: #d5e1e8;\n"
"	width: 100%;\n"
"	border-width: 1px;\n"
"	border-style: solid;\n"
"	border-color: #84b0c7;\n"
"	font-weight: bold;\n"
"	-moz-border-radius: 8px 8px 8px 8px;\n"
"}\n"
".paramkey {\n"
"	text-align: right;\n"
"}\n"
".paramtype {\n"
"	white-space: nowrap;\n"
"}\n"
".paramname {\n"
"	color: #602020;\n"
"	font-style: italic;\n"
"	white-space: nowrap;\n"
"}\n"
"/* End Styling for detailed member documentation */\n"
"\n"
"/* for the tree view */\n"
".ftvtree {\n"
"	font-family: sans-serif;\n"
"	margin:0.5em;\n"
"}\n"
".directory { \n"
"	font-size: 9pt; \n"
"	font-weight: bold; \n"
"}\n"
".directory h3 { \n"
"	margin: 0px; \n"
"	margin-top: 1em; \n"
"	font-size: 11pt; \n"
"}\n"
".directory > h3 { \n"
"	margin-top: 0; \n"
"}\n"
".directory p { \n"
"	margin: 0px; \n"
"	white-space: nowrap; \n"
"}\n"
".directory div { \n"
"	display: none; \n"
"	margin: 0px; \n"
"}\n"
".directory img { \n"
"	vertical-align: -30%; \n"
"}\n"
"\n"
